pub enum MicroStepResult<E, M: Model<E>> {
Continue(UncheckedActiveExecutor<E, M>),
Complete(ActiveExecutorContext<E, M>, MicroStepStatus),
}Expand description
The result of a micro-step execution.
This enum dictates the next phase of the simulation, differentiating between
whether execution should continue to the next micro-step (Continue) or
terminate the current tick (Complete).
Variants
Continue(UncheckedActiveExecutor<E, M>)
Indicates that the simulation can continue. The UncheckedActiveExecutor
is passed forward to be validated by the assigned ContinueStrategy.
Complete(ActiveExecutorContext<E, M>, MicroStepStatus)
Indicates that the current tick is finished. The ActiveExecutorContext
and the final MicroStepStatus are returned to finalize the tick’s state.